/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.util.actions;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.reflect.InvocationTargetException;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.SwingUtilities;
import org.junit.Test;
import org.openide.filesystems.FileObject;
import static org.mockito.Mockito.*;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class ActionsTest
  {
    private final String displayName = "displayName";
    private final String iconBase = "iconBase";
    
    @Test
    public void testAlwaysEnabled()
      throws InterruptedException, InvocationTargetException
      {
        final FileObject fileObject = mock(FileObject.class);
        final ActionListener delegate = mock(ActionListener.class);
        
        doReturn(delegate).when(fileObject).getAttribute(eq("delegate"));
        doReturn(displayName).when(fileObject).getAttribute(eq("displayName"));
        doReturn(iconBase).when(fileObject).getAttribute(eq("iconBase"));

        final Action action = Actions.alwaysEnabled(fileObject);
        assertThat((String)action.getValue(Action.NAME), is("displayName"));
        assertThat(action.isEnabled(), is(true));
//        assertThat((Icon)action.getValue(Action.SMALL_ICON), is(notNull())); TODO
        
        final ActionEvent event = mock(ActionEvent.class);

        SwingUtilities.invokeAndWait(new Runnable()
          {
            @Override
            public void run()
              {
                action.actionPerformed(event);
              }
          });

        verify(delegate).actionPerformed(same(event));
      }
  }